# environment.py - describe your project's virtualenv
# See the projectenv README for more information

# Specify the environment variables for your project's virtualenv.
environment_vars = {
}

# List the python packages to install for your project's virtualenv.
required_libs = read_requirements() + [
]
